;;; ControlTab.mrc - A Script / DLL combination that adds a Ctrl-Tab service

alias -l nop { }

alias ctLoad {
  ; Verify DCX is loaded, if it isn't load it from the local script directory
  if (!$script(dcx_tools.mrc)) { .load -rs $+(", $scriptdir, dcx_tools.mrc") }
  ; Load the DLL  
  if (!$dll(ControlTab.dll)) { echo -s Control-Bar DLL: $dll($+($scriptdir, ControlTab.dll), Load, 0) }
}
alias ctUnload { dll -u ControlTab.dll }
alias ctZOrder { nop $dll($+($scriptdir, ControlTab.dll), zOrder, $1) }
alias findwinname {
  var %xcid 1
  var %xwin | var %hwnd

  if ($1 !isnum) { return }
  while ($scon(%xcid)) {
    scid $scon(%xcid)
    set %xwin 1
    set %hwnd $window(*, %xwin).hwnd
    while (%hwnd) {
      if ($1 == %hwnd) { return $window(*, %xwin).cid $window(*, %xwin) }
      inc %xwin | set %hwnd $window(*, %xwin).hwnd
    }
    inc %xcid
  }
  return $null
}

on *:start:ctLoad
on *:load:ctLoad
on *:exit:ctUnload
on *:unload:ctUnload

#debug_ctrltab off
; This is #ifdef'd out of the DLL source also
on *:signal:CTRLTAB_DEBUG:{
  echo -s DEBUG: $1-
}
#debug_ctrltab end

; This signal can be used to determine the current Z-Order
on *:signal:CTRLTAB_ZORDER:{
  tokenize 32 $1 $2 $findwinname($2)
  ; Class = $1 ... HWND = $2 ... CID = $3 ... WindowName = $4-
  if ($3) {
    echo -a ZORDER: CID = $3 ... WindowName = $4-
  }
}

on *:signal:CTRLTAB_OPEN:{
  dialog -rmdo ControlTab ControlTab
}

on *:signal:CTRLTAB_CLOSE:{
  ;did -ra ControlTab 2 CtrlTab Signal: $signal $active
  dialog -x ControlTab
}

; This signal is sent anytime the ctrl-tab dialog is open and a window focus changes
; although the DLL sends CTRLTAB_TABNEXT events when a window focus changes, it is
; more reliable to also use the active event.
on *:active:*:{
  if ($dialog(ControlTab)) { .signal CTRLTAB_TABNEXT_ALT $active }
}
on *:signal:CTRLTAB_TABNEXT*:{
  var %Target $active
  var %picID 1 | var %Type $window($active).type

  ; Use the window type to display the proper icon loading it from mirc.exe
  if (%Type == status) set %picID 3
  else if (%Type == send) set %picID 7
  else if (%Type == get) set %picID 8
  else if (%Type == channel) set %picID 4
  else if (%Type == fserve) set %picID 10
  else if (%Type == query) set %picID 5
  else if (%Type == chat) set %picID 9
  else if (%Type == custom) set %picID 16
  else if (%Type == urls) set %picID 12
  else if (%Type == notify) set %picID 13
  else if (%Type == chanlist) set %picID 6
  did -g ControlTab 1 %picID $+(", $mircdir $+ mirc.exe, ")

  ; Setup the Description Text
  if (%Target  ischan) { did -ra ControlTab 2 $network $chr(91) $me $chr(93) $crlf $+ %Target $crlf $+ $chan(%Target).topic }
  else { did -ra ControlTab 2 $network $chr(91) $me $chr(93) $crlf $+ %Target }
}

dialog ControlTab {
  title "ControlTab"
  size -1 -1 200 45
  option dbu
  icon 1, 10 20 40 40
  edit "", 2, 40 10 155 40, read multi
}

on *:dialog:ControlTab:init:0:{
  .timer 1 0 showmirc -s
  ;did -ra ControlTab 2 CtrlTab Signal: CTRLTAB_OPEN $active
  nop $dcx(Mark, $dname dcx_control_tab)
  xdialog -b $dname +b
}

alias dcx_control_tab {

}

alias wintest {
  /query fwafew
  /query regegr
  /query gregre
  /query gergww
  /query juyjuy
  /query ewrwwe
  /query jyttjt
  /query cbxbfd
  /query retert
  /query fdsfss
  /query ewrwre
  /window -dD @gfnfgn
  /window -Dd @gregrf
}
